@@ -1179,3 +1179,13 @@ class Firebot:
                 return r.json()
             except:
                 attempts += 1
+
+    def getUsersinRoles(self, role):
+        """
+        Returns a list of all users assigned to a role
+        """
+        r = requests.get(self.url+f"/customroles")
+        data = r.json()
+        for i in data:
+            if role == i['name']:
+                return (i['viewers'])
\ No newline at end of file
